#!/bin/sh -e
# ==============================================================================
# portsreinstall library script
# Overlay onto lib/libmain.sh for portsreinstall-upgrade
# - Common functions of main programs -
# Copyright (C) 2018 Mamoru Sakaue, MwGhennndo, All Rights Reserved.
# This software is distributed under the 2-Clause BSD License.
# ==============================================================================

# ============= Save the previous configuration if exists =============
main_save_prev_conf ()
{
}

# ============= Load the saved configuration =============
main_load_conf ()
{
	. "${SAVEDCONF}"
}

# ============= Get complete configuration variable definitions by importing pkgtools.conf(5) if available =============
main_get_complete_conf ()
{
}

# ============= Parse the configuration =============
main_parse_conf ()
{
}
